15.34. cdist-type__debconf_set_selections(7) — cdist 4.10.4 documentation

# 15.34. cdist-type__debconf_set_selections(7)

## 15.34.1. NAME

cdist-type__debconf_set_selections - Setup debconf selections

## 15.34.2. DESCRIPTION

On Debian and alike systems debconf-set-selections(1) can be used to setup configuration parameters.

## 15.34.3. REQUIRED PARAMETERS

file
  Use the given filename as input for debconf-set-selections(1) If filename is "-", read from stdin.

## 15.34.4. EXAMPLES

    # Setup configuration for nslcd
    __debconf_set_selections nslcd --file /path/to/file

    # Setup configuration for nslcd from another type
    __debconf_set_selections nslcd --file "$__type/files/preseed/nslcd"

    __debconf_set_selections nslcd --file - << eof
    gitolite gitolite/gituser string git
    eof

## 15.34.5. SEE ALSO

debconf-set-selections(1), cdist-type__update_alternatives(7)

## 15.34.6. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 15.34.7. COPYING

Copyright (C) 2011-2014 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.